SystemOrganization addCategory: #GODSpreadsheetTests!

TestCase subclass: #GODSpreadsheetDataTest
	instanceVariableNames: 'godSSData'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODSpreadsheetTests'!

!GODSpreadsheetDataTest methodsFor: 'initializing' stamp: 'dhk 11/1/2014 00:52'!
setUp
	|file|
	
	file := FileStream fileNamed: 'ss_alo.csv'.
	file nextPutAll: 'um,dois,tres,quatro'; cr;
		nextPutAll: 'cinco,seis,sete,oito'; cr;
		nextPutAll: 'nove,dez,,"do,ze"'; cr;
		nextPutAll: 'treze,,,'; cr.
	file close.

	godSSData := SSSpreadsheetData new initialize.
	godSSData createSheetWithName: 'sheet1';
		createSheetWithName: 'sheet2';
		createSheetWithName: 'sheet3'.! !

!GODSpreadsheetDataTest methodsFor: 'testing' stamp: 'dhk 11/1/2014 00:53'!
testCSV2
	|spreadsheet1 spreadsheet2|

	spreadsheet1 := SSSpreadsheetData fromFile: 'ss_alo.csv'.
	(spreadsheet1 getSheet: 1) exportToCSV: 'ss_saidateste.csv'.
	spreadsheet2 := SSSpreadsheetData fromFile: 'ss_saidateste.csv'.
	
	self assert: (spreadsheet2) notNil.
	self assert: (spreadsheet1 = spreadsheet2).! !

!GODSpreadsheetDataTest methodsFor: 'testing' stamp: 'dhk 10/2/2014 21:39'!
testChangeName
	|sheet|
	sheet := godSSData getSheetWithName: 'sheet3'.
	godSSData renameSheet: 'sheet3' toName: 'super sheet'.
	self assert: (sheet name) = 'super sheet'.
	self assert: (godSSData getSheetWithName: 'super sheet') notNil.! !

!GODSpreadsheetDataTest methodsFor: 'testing' stamp: 'dhk 10/2/2014 21:33'!
testCreateSheet
	|tempGodSSData|

	tempGodSSData := SSSpreadsheetData new.

	tempGodSSData createSheetWithName: 'teste'.

	self assert: (tempGodSSData numberOfSheets) = 1.

	self assert: (tempGodSSData getSheet: 1) notNil.
	self assert: (tempGodSSData getSheetWithName: 'teste') notNil.! !

!GODSpreadsheetDataTest methodsFor: 'testing' stamp: 'dhk 11/1/2014 00:43'!
testFromCollection
	|data collection aux sheet|

	collection := OrderedCollection new.
	
	aux := OrderedCollection new.
	aux add: 'cel1'; add: 'cel2'; add: 'cel3'.
	collection add: aux.
	
	aux := OrderedCollection new.
	aux add: 'cel4'; add: 'cel5'; add: 'cel6'.
	collection add: aux.
	
	data := SSSpreadsheetData fromCollection: collection.
	
	sheet := data getSheet: 1.
	
	self assert: (sheet getCellAtRow: 1 atColumnIndex: 1) value = 'cel1'.
	self assert: (sheet getCellAtRow: 1 atColumnIndex: 2) value = 'cel2'.
	self assert: (sheet getCellAtRow: 1 atColumnIndex: 3) value = 'cel3'.
	
	self assert: (sheet getCellAtRow: 2 atColumnIndex: 1) value = 'cel4'.
	self assert: (sheet getCellAtRow: 2 atColumnIndex: 2) value = 'cel5'.
	self assert: (sheet getCellAtRow: 2 atColumnIndex: 3) value = 'cel6'.! !

!GODSpreadsheetDataTest methodsFor: 'testing' stamp: 'dhk 11/1/2014 00:45'!
testFromDictionary
	|data dict sheet|

	dict := Dictionary new.
	
	dict at: 'chave1' put: 'val1'; 
		at: 'chave2' put: 'val2';
		at: 'chave3' put: 'val3'.
	
	data := SSSpreadsheetData fromDictionary: dict.
	
	sheet := data getSheet: 1.
	
	self assert: (sheet getCellAtRow: 1 atColumnIndex: 1) value = 'chave1'.
	self assert: (sheet getCellAtRow: 1 atColumnIndex: 2) value = 'val1'.
	
	self assert: (sheet getCellAtRow: 2 atColumnIndex: 1) value = 'chave2'.
	self assert: (sheet getCellAtRow: 2 atColumnIndex: 2) value = 'val2'.
	
	self assert: (sheet getCellAtRow: 3 atColumnIndex: 1) value = 'chave3'.
	self assert: (sheet getCellAtRow: 3 atColumnIndex: 2) value = 'val3'.! !

!GODSpreadsheetDataTest methodsFor: 'testing' stamp: 'dhk 11/1/2014 00:53'!
testParseCSV
	| spreadsheet |

	spreadsheet := SSSpreadsheetData fromFile: 'ss_alo.csv'.
	
	self assert: (spreadsheet) notNil.! !

!GODSpreadsheetDataTest methodsFor: 'testing' stamp: 'foa 9/27/2014 18:38'!
testSheetsOrder
	|sheet1 sheet2|

	sheet1 := godSSData getSheet: 1.
	sheet2 := godSSData getSheetWithName: 'sheet1'.
	self assert: sheet1 == sheet2.

	sheet1 := godSSData getSheet: 2.
	sheet2 := godSSData getSheetWithName: 'sheet2'.

	self assert: sheet1 == sheet2.! !

TestCase subclass: #SSCellTest
	instanceVariableNames: 'ssCell'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODSpreadsheetTests'!

!SSCellTest methodsFor: 'testing' stamp: 'dhk 10/2/2014 21:40'!
testCellCreation
	|cell|

	cell := SSCell new.
	cell value: 'alo alo'.
	self assert: (cell value) = 'alo alo'! !

!SSCellTest methodsFor: 'testing' stamp: 'dhk 10/29/2014 21:51'!
testCellCreation2
	|sheet cell|

	sheet := SSSheet new: 'sheet1'.
	cell := sheet createCellAtRow: 2 atColumn: 'A' withValue: 'alo alo'.
	self assert: (cell value) = 'alo alo'.
	self assert: (cell column) = 'A'.
	self assert: (cell getRowIndex) = 2.
	self assert: (cell parent) == (sheet getRow: 2).
	self assert: (cell getColumnIndex) = 1.! !

!SSCellTest methodsFor: 'testing' stamp: 'dhk 10/29/2014 21:51'!
testCellParent
	|sheet row cell|

	sheet := SSSheet new: 'sheet1'.
	cell := sheet createCellAtRow: 2 atColumn: 'A' withValue: 'alo alo'.
	row := sheet getRow: 2.
	self assert: (cell parent) == row.
	self assert: (cell getParentRow) == row.! !

TestCase subclass: #SSRowTest
	instanceVariableNames: 'row sheet'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODSpreadsheetTests'!

!SSRowTest methodsFor: 'initializing' stamp: 'dhk 10/29/2014 18:09'!
setUp

	sheet := SSSheet new: 'sheet1'.
	row := sheet createRowAtIndex: 2.! !

!SSRowTest methodsFor: 'testing' stamp: 'dhk 11/1/2014 10:49'!
testCellOperations
	|cell1 cell2 cell3|
	cell1 := SSCell new.
	cell2 := SSCell new.
	cell3 := SSCell new.
	row addCell: cell1 atColumn: 'A'.
	row addCell: cell2 atColumnIndex: 2.
	row addCell: cell3 atColumn: 'C'.
	
	self assert: (row getCell: 'A') == cell1.
	self assert: (row getCellAtIndex: 2) == cell2.
	self assert: (row getCell: 'C') notNil.

	row clearCell: 'C'.
	row clearCellAtIndex: 2.

	self assert: (row getCell: 'C') notNil.
	self assert: ((row getCell: 'C') value) isNil.
	self assert: (row getCellAtIndex: 2) notNil.
	self assert: ((row getCellAtIndex: 2) value) isNil.! !

!SSRowTest methodsFor: 'testing' stamp: 'dhk 10/17/2014 18:33'!
testOneColumn
	|cell1|
	cell1 := SSCell new.
	row addCell: cell1 atColumnIndex: 1.
	
	self assert: (row getCellAtIndex: 1) == cell1.! !

!SSRowTest methodsFor: 'testing' stamp: 'dhk 10/29/2014 18:10'!
testRowIndex

	self assert: (row index) = 2.! !

!SSRowTest methodsFor: 'testing' stamp: 'dhk 10/29/2014 18:09'!
testRowParent

	self assert: (row parent) = sheet.! !

TestCase subclass: #SSSheetTest
	instanceVariableNames: 'sheet'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODSpreadsheetTests'!

!SSSheetTest methodsFor: 'initializing' stamp: 'foa 9/27/2014 18:29'!
setUp

	sheet := SSSheet new: 'sheet1'.! !

!SSSheetTest methodsFor: 'testing' stamp: 'dhk 10/29/2014 22:17'!
testALot 

	| ssData sheet cell |
	ssData := SSSpreadsheetData new.
	sheet := ssData createSheetWithName: 'zubat'.
	cell := sheet createCellAtRow: 1 atColumn: 'A' withValue: 32.
	self assert: (sheet getCellAtRow: 1 atColumn: 'A') == cell.
	self assert: (sheet getCellAtRow: 1 atColumnIndex: 1) == cell.
	
	cell := sheet createCellAtRow: 4 atColumnIndex: 4 withValue: 42.
	self assert: (sheet getCellAtRow: 4 atColumn: 'D') == cell.
	self assert: (sheet getCellAtRow: 4 atColumnIndex: 4) == cell.
	
	self assert: (sheet index) = 1.! !

!SSSheetTest methodsFor: 'testing' stamp: 'dhk 10/2/2014 21:39'!
testName

	self assert: (sheet name) = 'sheet1'.

	sheet changeName: 'sheet2'.
	self assert: (sheet name) = 'sheet2'.! !

!SSSheetTest methodsFor: 'testing' stamp: 'dhk 10/29/2014 21:55'!
testParent

	| ssData sheet |
	ssData := SSSpreadsheetData new.
	sheet := ssData createSheetWithName: 'zubat'.
	self assert: (sheet parent) = ssData.! !

!SSSheetTest methodsFor: 'testing' stamp: 'dhk 10/17/2014 19:34'!
testRowOperations

	| row1 row2 cell1 cell2 |

	row1 := sheet createRow.
	row2 := sheet createRowAtIndex: 3.

	self assert: (sheet getRow: 1) == row1.
	self assert: (sheet getRow: 3) == row2.

	sheet deleteRow: 3. 
	self should: [sheet getRow: 3] raise: Error.

	cell1 := SSCell new.
	cell2 := SSCell new.

	row1 addCell: cell1 atColumn: 'A';
		   addCell: cell2 atColumn: 'B'.

	self assert: (sheet getCellAtRow: 1 atColumn: 'A') == cell1.
	self assert: (sheet getCellAtRow: 1 atColumnIndex: 2) == cell2.! !

!SSSheetTest methodsFor: 'testing' stamp: 'dhk 11/1/2014 12:12'!
testSort

	| x c ssData sheet|
	x := OrderedCollection new.
	
	c := OrderedCollection new.
	c add: 1; add: 'b1'; add: 'c1'.
	x add: c.
	
	c := OrderedCollection new.
	c add: 6; add: 'b2'; add: 'c2'.
	x add: c.
	
	c := OrderedCollection new.
	c add: 9; add: 'b3'; add: 'c3'.
	x add: c.
	
	c := OrderedCollection new.
	c add: nil; add: 'b4'; add: 'c4'.
	x add: c.
	
	c := OrderedCollection new.
	c add: 7; add: 'b5'; add: 'c5'.
	x add: c.



	ssData := SSSpreadsheetData fromCollection: x.
	sheet := ssData getSheet: 1.
	
	sheet sort.
	
	self assert: (sheet getCellAtRow: 1 atColumnIndex: 1) value = 1.
	self assert: (sheet getCellAtRow: 1 atColumnIndex: 2) value = 'b1'.
	self assert: (sheet getCellAtRow: 1 atColumnIndex: 3) value = 'c1'.

	self assert: (sheet getCellAtRow: 2 atColumnIndex: 1) value = 6.
	self assert: (sheet getCellAtRow: 2 atColumnIndex: 2) value = 'b2'.
	self assert: (sheet getCellAtRow: 2 atColumnIndex: 3) value = 'c2'.
	
	self assert: (sheet getCellAtRow: 3 atColumnIndex: 1) value = 7.
	self assert: (sheet getCellAtRow: 3 atColumnIndex: 2) value = 'b5'.
	self assert: (sheet getCellAtRow: 3 atColumnIndex: 3) value = 'c5'.
	
	self assert: (sheet getCellAtRow: 4 atColumnIndex: 1) value = 9.
	self assert: (sheet getCellAtRow: 4 atColumnIndex: 2) value = 'b3'.
	self assert: (sheet getCellAtRow: 4 atColumnIndex: 3) value = 'c3'.
	
	self assert: (sheet getCellAtRow: 5 atColumnIndex: 1) value isNil.
	self assert: (sheet getCellAtRow: 5 atColumnIndex: 2) value = 'b4'.
	self assert: (sheet getCellAtRow: 5 atColumnIndex: 3) value = 'c4'.! !

!SSSheetTest methodsFor: 'testing' stamp: 'dhk 11/1/2014 12:15'!
testSortFrom

	| x c ssData sheet|
	x := OrderedCollection new.
	
	c := OrderedCollection new.
	c add: 6; add: 'b1'; add: 'c1'.
	x add: c.
	
	c := OrderedCollection new.
	c add: 1; add: 'b2'; add: 'c2'.
	x add: c.
	
	c := OrderedCollection new.
	c add: 9; add: 'b3'; add: 'c3'.
	x add: c.
	
	c := OrderedCollection new.
	c add: nil; add: 'b4'; add: 'c4'.
	x add: c.
	
	c := OrderedCollection new.
	c add: 7; add: 'b5'; add: 'c5'.
	x add: c.



	ssData := SSSpreadsheetData fromCollection: x.
	sheet := ssData getSheet: 1.
	
	sheet sortFrom: 2.
	
	self assert: (sheet getCellAtRow: 1 atColumnIndex: 1) value = 6.
	self assert: (sheet getCellAtRow: 1 atColumnIndex: 2) value = 'b1'.
	self assert: (sheet getCellAtRow: 1 atColumnIndex: 3) value = 'c1'.

	self assert: (sheet getCellAtRow: 2 atColumnIndex: 1) value = 1.
	self assert: (sheet getCellAtRow: 2 atColumnIndex: 2) value = 'b2'.
	self assert: (sheet getCellAtRow: 2 atColumnIndex: 3) value = 'c2'.
	
	self assert: (sheet getCellAtRow: 3 atColumnIndex: 1) value = 7.
	self assert: (sheet getCellAtRow: 3 atColumnIndex: 2) value = 'b5'.
	self assert: (sheet getCellAtRow: 3 atColumnIndex: 3) value = 'c5'.
	
	self assert: (sheet getCellAtRow: 4 atColumnIndex: 1) value = 9.
	self assert: (sheet getCellAtRow: 4 atColumnIndex: 2) value = 'b3'.
	self assert: (sheet getCellAtRow: 4 atColumnIndex: 3) value = 'c3'.
	
	self assert: (sheet getCellAtRow: 5 atColumnIndex: 1) value isNil.
	self assert: (sheet getCellAtRow: 5 atColumnIndex: 2) value = 'b4'.
	self assert: (sheet getCellAtRow: 5 atColumnIndex: 3) value = 'c4'.! !

!SSSheetTest methodsFor: 'testing' stamp: 'dhk 11/1/2014 12:20'!
testSortFromTo

	| x c ssData sheet|
	x := OrderedCollection new.
	
	c := OrderedCollection new.
	c add: 6; add: 'b1'; add: 'c1'.
	x add: c.
	
	c := OrderedCollection new.
	c add: 9; add: 'b2'; add: 'c2'.
	x add: c.
	
	c := OrderedCollection new.
	c add: nil; add: 'b3'; add: 'c3'.
	x add: c.
	
	c := OrderedCollection new.
	c add: 7; add: 'b4'; add: 'c4'.
	x add: c.

	c := OrderedCollection new.
	c add: 1; add: 'b5'; add: 'c5'.
	x add: c.

	ssData := SSSpreadsheetData fromCollection: x.
	sheet := ssData getSheet: 1.
	
	sheet sortFrom: 2 to: 4.
	
	self assert: (sheet getCellAtRow: 1 atColumnIndex: 1) value = 6.
	self assert: (sheet getCellAtRow: 1 atColumnIndex: 2) value = 'b1'.
	self assert: (sheet getCellAtRow: 1 atColumnIndex: 3) value = 'c1'.
	
	self assert: (sheet getCellAtRow: 2 atColumnIndex: 1) value = 7.
	self assert: (sheet getCellAtRow: 2 atColumnIndex: 2) value = 'b4'.
	self assert: (sheet getCellAtRow: 2 atColumnIndex: 3) value = 'c4'.
	
	self assert: (sheet getCellAtRow: 3 atColumnIndex: 1) value = 9.
	self assert: (sheet getCellAtRow: 3 atColumnIndex: 2) value = 'b2'.
	self assert: (sheet getCellAtRow: 3 atColumnIndex: 3) value = 'c2'.
	
	self assert: (sheet getCellAtRow: 4 atColumnIndex: 1) value isNil.
	self assert: (sheet getCellAtRow: 4 atColumnIndex: 2) value = 'b3'.
	self assert: (sheet getCellAtRow: 4 atColumnIndex: 3) value = 'c3'.
	
	self assert: (sheet getCellAtRow: 5 atColumnIndex: 1) value = 1.
	self assert: (sheet getCellAtRow: 5 atColumnIndex: 2) value = 'b5'.
	self assert: (sheet getCellAtRow: 5 atColumnIndex: 3) value = 'c5'.! !
